document.addEventListener('DOMContentLoaded', () => {
    const searchBtn = document.getElementById('search-btn');
    const addressInput = document.getElementById('address-input');

    const mockData = {
        safety: 85,
        transit: 72,
        green: 68,
        services: 90
    };

    searchBtn.addEventListener('click', () => {
        if (addressInput.value.trim() === '') {
            alert('Please enter an address');
            return;
        }
        
        // Simulate API call with loading state
        updateScores('--');
        setTimeout(() => {
            updateScores(mockData);
            updateDetails();
        }, 1500);
    });

    function updateScores(data) {
        if (data === '--') {
            document.querySelectorAll('.score span').forEach(span => {
                span.textContent = '--';
            });
            return;
        }

        animateValue('safety-score', data.safety);
        animateValue('transit-score', data.transit);
        animateValue('green-score', data.green);
        animateValue('services-score', data.services);
    }

    function animateValue(elementId, value) {
        const element = document.getElementById(elementId).querySelector('span');
        let current = 0;
        const increment = value / 30;
        const timer = setInterval(() => {
            current += increment;
            if (current >= value) {
                current = value;
                clearInterval(timer);
            }
            element.textContent = Math.round(current);
        }, 20);
    }

    function updateDetails() {
        const lists = {
            'healthcare-list': ['Hospital - 1.2km', 'Clinic - 0.5km', 'Pharmacy - 0.3km'],
            'education-list': ['Primary School - 0.8km', 'High School - 1.5km', 'Library - 1.0km'],
            'recreation-list': ['Park - 0.4km', 'Sports Center - 1.1km', 'Pool - 1.8km'],
            'services-list': ['Grocery Store - 0.3km', 'Post Office - 0.7km', 'Bank - 0.5km']
        };

        Object.entries(lists).forEach(([listId, items]) => {
            const ul = document.getElementById(listId);
            ul.innerHTML = '';
            items.forEach(item => {
                const li = document.createElement('li');
                li.textContent = item;
                ul.appendChild(li);
            });
        });
    }
});
